IF YOU ARE REPORTING A BUG OR PROBLEM WITH DLIB THEN FILL OUT THE ENTIRE TEMPLATE BELOW.  ISSUES ASKING QUESTIONS ABOUT WHY SOMETHING DOESN'T WORK THAT FAIL TO FILL OUT THE ENTIRE TEMPLATE WILL BE CLOSED.

It is OK to suggest interesting improvements to dlib, even if you are not volunteering to implement them.  **However, the issue tracker is not a code writing service, do not ask for someone to write code for you.**  E.g. Do not ask for feature improvements to the example programs. **If there is some feature improvement you want in an example program then it's up to you to write it**.  

Before you ask a question, check Google for a solution, [the dlib FAQ](http://dlib.net/faq.html), or consult the dlib documentation.  Every single function in dlib is documented in detail.  If you obviously haven't read the documentation your issue will be closed.  

If you aren't reporting a bug or problem with dlib then delete this template and write whatever you want here.
 
<!-- ================================================================== -->
<!-- ==================  BUG/PROBLEM REPORT TEMPLATE ================== -->
<!-- ================================================================== -->


<!-- Delete the above instructions and then provide a general summary of the issue in the Title above.  Then fill out the template below.  FAILURE TO FILL OUT EVERY PART WILL RESULT IN YOUR ISSUE BEING CLOSED -->

## Expected Behavior
<!--- Tell us what should happen.  What were you doing?  What part of dlib are you using?  What do you think should happen? -->

## Current Behavior
<!--- Tell us what happens instead of the expected behavior.  If you get an error, include the entire error message in the bug report.  DO NOT POST SCREEN SHOTS.  Paste in the text instead.   If the issue is some kind of build problem, include the entire CMake output along with the error message. -->

## Steps to Reproduce
<!--- Provide an unambiguous set of steps to reproduce this problem.  What exactly do I have to type to reproduce your error?  If you don't post complete instructions you are much less likely to get help. -->



* **Version**: <!-- What version of dlib? -->
* **Where did you get dlib**: <!-- Did you get it from an official source like dlib.net, this github repo, or somewhere else? -->
* **Platform**: <!-- include something like `lsb_release -a` output, or if Windows, version and 32-bit or
  64-bit -->
* **Compiler**: <!-- What compiler are you using?  What version of that compiler? -->
